==> v3.12.4.8.tar.gz: qcad-3.12.4.8/ts/qcadgui_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>ExitTrialDialog</name>
    <message>
        <source>Trial Version</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wersja próbna</translation>
    </message>
    <message>
        <source>QCAD Trial</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">QCad Trial</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Cannot find user manual at: %1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Nie można znaleźć instrukcję na:</translation>
    </message>
    <message>
        <source>Unable to launch Qt Assistant (%1)</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
Nie można uruchomić Qt Assistant (%1)</translatorcomment>
        <translation type="obsolete">Nie można uruchomić Qt Assistant (%1)</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+126"/>
        <source>Custom</source>
        <translatorcomment>--exact match--
--file: qvfb_pl.ts--
Niestandardowe..
Niestandardowy
Własne filtry</translatorcomment>
        <translation>Niestandardowy</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+156"/>
        <source>Invalid</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RSingleApplication</name>
    <message>
        <source>This software is not intended for production use.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Ten program nie jest przeznaczony do użycia w produkcji.</translation>
    </message>
    <message>
        <source>To continue trying out QCAD, please restart the software.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Aby kontynuować wypróbowanie QCad, należy ponownie uruchomić oprogramowanie.</translation>
    </message>
    <message>
        <source>To start using QCAD without any limitations, please buy the full version for a small license fee from %1.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Aby rozpocząć korzystanie z QCad bez ograniczeń, należy kupić pełną wersję za niewielką opłatą licencyjnej.</translation>
    </message>
</context>
</TS>

==> v3.22.1.2.tar.gz: qcad-3.22.1.2/ts/qcadgui_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ExitTrialDialog</name>
    <message>
        <source>Trial Version</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wersja próbna</translation>
    </message>
    <message>
        <source>QCAD Trial</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">QCad Trial</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Cannot find user manual at: %1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Nie można znaleźć instrukcję na:</translation>
    </message>
    <message>
        <source>Unable to launch Qt Assistant (%1)</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
Nie można uruchomić Qt Assistant (%1)</translatorcomment>
        <translation type="obsolete">Nie można uruchomić Qt Assistant (%1)</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+126"/>
        <source>Custom</source>
        <translatorcomment>--exact match--
--file: qvfb_pl.ts--
Niestandardowe..
Niestandardowy
Własne filtry</translatorcomment>
        <translation>Dostosowany</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+195"/>
        <source>Grid</source>
        <translation>Siatka</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Koniec</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>Na obiekcie</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Prostopadle</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Stycznie</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Centrum</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Środek</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Przecięcie</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Odniesienie</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+171"/>
        <source>Invalid</source>
        <translation>Nieprawidłowy</translation>
    </message>
</context>
<context>
    <name>RSingleApplication</name>
    <message>
        <source>This software is not intended for production use.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Ten program nie jest przeznaczony do użycia w produkcji.</translation>
    </message>
    <message>
        <source>To continue trying out QCAD, please restart the software.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Aby kontynuować wypróbowanie QCad, należy ponownie uruchomić oprogramowanie.</translation>
    </message>
    <message>
        <source>To start using QCAD without any limitations, please buy the full version for a small license fee from %1.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Aby rozpocząć korzystanie z QCad bez ograniczeń, należy kupić pełną wersję za niewielką opłatą licencyjnej.</translation>
    </message>
</context>
</TS>
